==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/sn_blocked.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

include "inc/header_sn.inc.php";

$sn->date = $date;
$output_blocked = "";


if (isset($_REQUEST['unblock_user_id'])) {
    $user_blocked = $sn->unSetBlockUser($_REQUEST['unblock_user_id']);
}
else {
	$output_blocked = $sn->getBlockedUsers();
}


//move to template
if (!empty($output_profile)) {
   $body->set('profile', $output_profile);
}

if (!empty($display)) {
   $body->set('display', $display);
}

if (!empty($output_blocked)) {
   $body->set('blocked', $output_blocked);
}

include "inc/footer.inc.php";

?>

==> aroundme_0_6_7.zip: aroundme_0_6_7/aroundme/sn_blocked.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include "inc/header_sn.inc.php";


// SETUP LANGUAGE --------------------------------------------------------
require_once($languagePath . 'common.lang.php');
require_once($languagePath . 'sn_common.lang.php');


if (isset($_REQUEST['unblock_user_id'])) {
	$sn->user_id = $me['user_id'];
    $user_blocked = $sn->unSetBlockUser($_REQUEST['unblock_user_id']);
}

$output_blocked = $sn->getBlockedUsers();

//move to template
if (!empty($output_profile)) {
   $body->set('profile', $output_profile);
}

if (!empty($display)) {
   $body->set('display', $display);
}

if (!empty($output_blocked)) {
   $body->set('blocked', $output_blocked);
}

include "inc/footer.inc.php";

?>
